/* $Id: weatherservice.cpp,v 1.16 2003/05/01 19:30:37 geiseri Exp $ */
#include <kdebug.h>
#include <kapplication.h>
#include <kconfig.h>
#include <kstandarddirs.h>

#include "weatherlib.h"
#include "weatherservice.h"

WeatherService::WeatherService() : QObject (0,"WeatherService"),  DCOPObject("WeatherService")
{
	kdDebug(12004) << "Starting new service... " << endl;
	m_weatherLib = new WeatherLib;
	connect(m_weatherLib, SIGNAL(fileUpdating( const QString&)),
			SLOT(updating( const QString&)));
	connect(m_weatherLib, SIGNAL(fileUpdate( const QString&)),
			SLOT(updated( const QString&)));

	KConfig *conf = kapp->config();

	conf->setGroup("WEATHERSTATIONS");
	QStringList stations =conf->readListEntry("stations");
	for ( QStringList::Iterator it = stations.begin (); it != stations.end(); ++it )
		m_weatherLib->update(*it);
	//kapp->config()->setGroup("Weather Service Options");
	//reportLocation = kapp->config()->readEntry("report_location", "none");
	//kapp->config()->sync();
}

WeatherService::~WeatherService()
{
	kdDebug(12004) << "Going away... " << endl;
	KConfig *conf = kapp->config();
	conf->setGroup("WEATHERSTATIONS");
	conf->writeEntry( "stations", m_weatherLib->stations());
	conf->sync();
}

void WeatherService::updated(const QString &stationID)
{
	kdDebug(12004) << "Sending update for " << stationID << endl;
	fileUpdate( stationID );
}

void WeatherService::updateAll()
{
	kdDebug(12004) << "Sending for all" << endl;
	QStringList stations =  m_weatherLib->stations();
	for  ( QStringList::Iterator it = stations.begin(); it != stations.end(); ++it ) {
		update(*it);
    	}

}

void WeatherService::updating(const QString &stationID)
{
	kdDebug(12004) << "Sending updating for " << stationID << endl;
	fileUpdating( stationID );
}


QString WeatherService::temperature(const QString &stationID)
{
	kdDebug (12004) << "Returning " << stationID << endl;
	return m_weatherLib->temperature(stationID);
}

QString WeatherService::dewPoint(const QString &stationID)
{
	return m_weatherLib->dewPoint(stationID);
}

QString WeatherService::relativeHumidity(const QString &stationID)
{
	return m_weatherLib->relHumidity(stationID);
}

QString WeatherService::heatIndex(const QString &stationID)
{
	return m_weatherLib->heatIndex(stationID);
}

QString WeatherService::windChill(const QString &stationID)
{
	return m_weatherLib->windChill(stationID);
}

QString WeatherService::wind(const QString &stationID)
{
	return m_weatherLib->wind(stationID);
}

QString WeatherService::pressure(const QString &stationID)
{
	return m_weatherLib->pressure(stationID);
}

QPixmap WeatherService::currentIcon(const QString &stationID)
{
	kdDebug(12004) << "Get the current weather icon.." << endl;
	QString icon  = m_weatherLib->currentIcon(stationID);
	QString theImage = "kweather/" + icon + ".png";
	kdDebug(12004) << "Icon: " << theImage << endl;
	QPixmap theIcon = QPixmap(locate("data", theImage));
	return theIcon;
}

QString WeatherService::currentIconString(const QString &stationID)
{
	return m_weatherLib->currentIcon(stationID);
}

QString WeatherService::date(const QString &stationID)
{
	return m_weatherLib->date(stationID);
}

QString WeatherService::visability(const QString &stationID)
{
	return m_weatherLib->visibility(stationID);
}

QStringList WeatherService::cover(const QString &stationID)
{
	return m_weatherLib->cover(stationID);
}

QStringList WeatherService::weather(const QString &stationID)
{
	return m_weatherLib->weather(stationID);
}
void WeatherService::update(const QString &stationID)
{
	m_weatherLib->update(stationID);
}

void WeatherService::forceUpdate(const QString &stationID)
{
	m_weatherLib->blockingUpdate(stationID);
}

void WeatherService::removeStation(const QString &stationID)
{
	m_weatherLib->remove(stationID);
}

void WeatherService::addStation(const QString &stationID)
{
	m_weatherLib->update(stationID);
}

/*
void WeatherService::setMaxAge(int age)
{

}

int WeatherService::maxAge()
{

}
*/

void WeatherService::exit()
{
	KConfig *conf = kapp->config();
	conf->setGroup("WEATHERSTATIONS");
	conf->writeEntry( "stations", m_weatherLib->stations());
	conf->sync();
	kapp->quit();
}

QStringList WeatherService::listStations()
{
	return m_weatherLib->stations();
}

#include "weatherservice.moc"
